% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/user.R
\name{userIdentity}
\alias{userIdentity}
\title{Get User Identity}
\usage{
userIdentity()
}
\description{
Returns the identity (displayed name) of the current user.
}
