% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/terminal.R
\name{terminalBuffer}
\alias{terminalBuffer}
\title{Get Terminal Buffer}
\usage{
terminalBuffer(id, stripAnsi = TRUE)
}
\arguments{
\item{id}{The terminal id. The \code{id} is obtained from
\code{\link{terminalList}()}, \code{\link{terminalVisible}()},
\code{\link{terminalCreate}()}, or \code{\link{terminalExecute}()}.}

\item{stripAnsi}{If FALSE, don't strip out Ansi escape sequences before returning
terminal buffer.}
}
\value{
The terminal contents, one line per row.
}
\description{
Returns contents of a terminal buffer.
}
\note{
The \code{terminalBuffer} function was added in version 1.1.350 of RStudio.
}
