% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/user.R
\name{systemUsername}
\alias{systemUsername}
\title{Get System Username}
\usage{
systemUsername()
}
\description{
Returns the system username of the current user.
}
